Index: chrome/common/metrics/version_utils.h |
diff --git a/chrome/common/metrics/version_utils.h b/chrome/common/metrics/version_utils.h |
index f1491a1e27ed7f76125564e82d26684b85d9ed23..389c22791dbaa9320584ed82cefe418a288ea666 100644 |
--- a/chrome/common/metrics/version_utils.h |
+++ b/chrome/common/metrics/version_utils.h |
@@ -16,10 +16,10 @@ namespace metrics { |
// platforms, and "-devel" on developer builds. |
std::string GetVersionString(); |
// Translates chrome::VersionInfo::Channel to the equivalent |
// SystemProfileProto::Channel. |
SystemProfileProto::Channel AsProtobufChannel( |
- chrome::VersionInfo::Channel channel); |
+ version_info::Channel channel); |
} // namespace metrics |
@@ -16,10 +16,10 @@ namespace metrics { |
// platforms, and "-devel" on developer builds. |
std::string GetVersionString(); |
-// Translates chrome::VersionInfo::Channel to the equivalent |
+// Translates version_info::Channel to the equivalent |
// SystemProfileProto::Channel. |
SystemProfileProto::Channel AsProtobufChannel( |